-- создание таблицы аудита, секции создаются в процессе работы
CREATE TABLE IF NOT EXISTS audit_db (
     logid bigserial not null,
     datetime timestamptz NOT NULL,
     kind int4 NOT NULL,
     httppath varchar(255) NULL,
     entity varchar(100) NULL,
     proguser jsonb NULL,
     idvalue _int4 NULL,
     inputobject jsonb NULL,
     outputobject jsonb NULL,
     faultinfo varchar(1000) NULL,
     duration int8 null,
     schemaname varchar(20) null,
     score tsvector
) PARTITION BY RANGE (datetime)^

CREATE INDEX IF NOT EXISTS audit_db_ts_idx ON audit_db USING GIN(score)^

-- формирование ts vector по данным перед вставкой новой записи
CREATE OR REPLACE FUNCTION audit_ts_calc()
    RETURNS trigger
    LANGUAGE plpgsql
AS $function$
BEGIN
    new.score=to_tsvector('russian',new.inputobject) ||
              to_tsvector('russian',new.outputobject) ||
              to_tsvector('russian',coalesce(new.faultinfo,''));
    return new;
END;
$function$
^

-- обновление триггера для вычисления ts vector
DROP TRIGGER IF EXISTS audit_ts_trigger ON audit_db^
CREATE TRIGGER audit_ts_trigger BEFORE INSERT OR UPDATE ON audit_db FOR EACH ROW EXECUTE FUNCTION audit_ts_calc()^
